@@ -15,5 +15,8 @@ Dummy
 Dummy objects are passed around but never validated.
 
 """
-from ludibrio import Mock, Stub, Dummy
+from ludibrio.mock import Mock
+from ludibrio.stub import Stub
+from ludibrio.dummy import Dummy
 
+from ludibrio.matcher import *
